@@ -1,8 +1,7 @@
 /*
  *      plugindata.h - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2007-2012 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
- *      Copyright 2007-2012 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
+ *      Copyright 2007 The Geany contributors
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -32,7 +31,6 @@
 #ifndef GEANY_PLUGIN_DATA_H
 #define GEANY_PLUGIN_DATA_H 1
 
-#include "geany.h"  /* for GEANY_DEPRECATED */
 #include "build.h"  /* GeanyBuildGroup, GeanyBuildSource, GeanyBuildCmdEntries enums */
 #include "document.h" /* GeanyDocument */
 #include "editor.h"	/* GeanyEditor, GeanyIndentType */
@@ -59,21 +57,18 @@ G_BEGIN_DECLS
  * @warning You should not test for values below 200 as previously
  * @c GEANY_API_VERSION was defined as an enum value, not a macro.
  */
-#define GEANY_API_VERSION 230
+#define GEANY_API_VERSION 247
 
-/* hack to have a different ABI when built with GTK3 because loading GTK2-linked plugins
- * with GTK3-linked Geany leads to crash */
-#if GTK_CHECK_VERSION(3, 0, 0)
-#	define GEANY_ABI_SHIFT 8
-#else
-#	define GEANY_ABI_SHIFT 0
-#endif
+/* hack to have a different ABI when built with different GTK major versions
+ * because loading plugins linked to a different one leads to crashes.
+ * Only GTK3 is currently supported. */
+#define GEANY_ABI_SHIFT 8
 /** The Application Binary Interface (ABI) version, incremented whenever
  * existing fields in the plugin data types have to be changed or reordered.
  * Changing this forces all plugins to be recompiled before Geany can load them. */
 /* This should usually stay the same if fields are only appended, assuming only pointers to
  * structs and not structs themselves are declared by plugins. */
-#define GEANY_ABI_VERSION (71 << GEANY_ABI_SHIFT)
+#define GEANY_ABI_VERSION (73 << GEANY_ABI_SHIFT)
 
 
 /** Defines a function to check the plugin is safe to load.
@@ -315,6 +310,7 @@ gboolean geany_plugin_register(GeanyPlugin *plugin, gint api_version,
 gboolean geany_plugin_register_full(GeanyPlugin *plugin, gint api_version,
                                     gint min_api_version, gint abi_version,
                                     gpointer data, GDestroyNotify free_func);
+gpointer geany_plugin_get_data(const GeanyPlugin *plugin);
 void geany_plugin_set_data(GeanyPlugin *plugin, gpointer data, GDestroyNotify free_func);
 
 /** Convenience macro to register a plugin.
@@ -345,29 +341,17 @@ void geany_plugin_set_data(GeanyPlugin *plugin, gpointer data, GDestroyNotify fr
  */
 typedef enum
 {
-	/** @deprecated Use GEANY_PROXY_IGNORE instead.
-	 * @since 1.26 (API 226)
-	 */
-	PROXY_IGNORED,
-	/** @deprecated Use GEANY_PROXY_MATCH instead.
-	 * @since 1.26 (API 226)
-	 */
-	PROXY_MATCHED,
-	/** @deprecated Use GEANY_PROXY_RELATED instead.
-	 * @since 1.26 (API 226)
-	 */
-	PROXY_NOLOAD = 0x100,
 	/** The proxy is not responsible at all, and Geany or other plugins are free
 	 * to probe it.
 	 *
 	 * @since 1.29 (API 229)
 	 **/
-	GEANY_PROXY_IGNORE = PROXY_IGNORED,
+	GEANY_PROXY_IGNORE,
 	/** The proxy is responsible for this file, and creates a plugin for it.
 	 *
 	 * @since 1.29 (API 229)
 	 */
-	GEANY_PROXY_MATCH = PROXY_MATCHED,
+	GEANY_PROXY_MATCH,
 	/** The proxy is does not directly load it, but it's still tied to the proxy.
 	 *
 	 * This is for plugins that come in multiple files where only one of these
@@ -378,11 +362,10 @@ typedef enum
 	 *
 	 * @since 1.29 (API 229)
 	 */
-	GEANY_PROXY_RELATED = PROXY_MATCHED | PROXY_NOLOAD
+	GEANY_PROXY_RELATED = GEANY_PROXY_MATCH | 0x100
 }
 GeanyProxyProbeResults;
 
-
 /** Hooks that need to be implemented by every proxy
  *
  * @see geany_plugin_register_proxy() for a full description of the proxy mechanism.
@@ -402,78 +385,6 @@ struct GeanyProxyFuncs
 
 gint geany_plugin_register_proxy(GeanyPlugin *plugin, const gchar **extensions);
 
-/* Deprecated aliases */
-#ifndef GEANY_DISABLE_DEPRECATED
-
-/* This remains so that older plugins that contain a `GeanyFunctions *geany_functions;`
- * variable in their plugin - as was previously required - will still compile
- * without changes.  */
-typedef struct GeanyFunctionsUndefined GeanyFunctions GEANY_DEPRECATED;
-
-/** @deprecated - use plugin_set_key_group() instead.
- * @see PLUGIN_KEY_GROUP() macro. */
-typedef struct GeanyKeyGroupInfo
-{
-	const gchar *name;		/**< Group name used in the configuration file, such as @c "html_chars" */
-	gsize count;			/**< The number of keybindings the group will hold */
-}
-GeanyKeyGroupInfo GEANY_DEPRECATED_FOR(plugin_set_key_group);
-
-/** @deprecated - use plugin_set_key_group() instead.
- * Declare and initialise a keybinding group.
- * @code GeanyKeyGroup *plugin_key_group; @endcode
- * You must then set the @c plugin_key_group::keys[] entries for the group in plugin_init(),
- * normally using keybindings_set_item().
- * The @c plugin_key_group::label field is set by Geany after @c plugin_init()
- * is called, to the name of the plugin.
- * @param group_name A unique group name (without quotes) to be used in the
- * configuration file, such as @c html_chars.
- * @param key_count	The number of keybindings the group will hold. */
-#define PLUGIN_KEY_GROUP(group_name, key_count) \
-	/* We have to declare this as a single element array.
-	 * Declaring as a pointer to a struct doesn't work with g_module_symbol(). */ \
-	GeanyKeyGroupInfo plugin_key_group_info[1] = \
-	{ \
-		{G_STRINGIFY(group_name), key_count} \
-	};\
-	GeanyKeyGroup *plugin_key_group = NULL;
-
-/** @deprecated Use @ref ui_add_document_sensitive() instead.
- * Flags to be set by plugins in PluginFields struct. */
-typedef enum
-{
-	/** Whether a plugin's menu item should be disabled when there are no open documents */
-	PLUGIN_IS_DOCUMENT_SENSITIVE	= 1 << 0
-}
-PluginFlags;
-
-/** @deprecated Use @ref ui_add_document_sensitive() instead.
- * Fields set and owned by the plugin. */
-typedef struct PluginFields
-{
-	/** Bitmask of @c PluginFlags. */
-	PluginFlags	flags;
-	/** Pointer to a plugin's menu item which will be automatically enabled/disabled when there
-	 *  are no open documents and @c PLUGIN_IS_DOCUMENT_SENSITIVE is set.
-	 *  This is required if using @c PLUGIN_IS_DOCUMENT_SENSITIVE, ignored otherwise */
-	GtkWidget	*menu_item;
-}
-PluginFields GEANY_DEPRECATED_FOR(ui_add_document_sensitive);
-
-#define document_reload_file document_reload_force
-
-/** @deprecated - copy into your plugin code if needed.
- * @c NULL-safe way to get the index of @a doc_ptr in the documents array. */
-#define DOC_IDX(doc_ptr) \
-	(doc_ptr ? doc_ptr->index : -1)
-#define DOC_IDX_VALID(doc_idx) \
-	((doc_idx) >= 0 && (guint)(doc_idx) < documents_array->len && documents[doc_idx]->is_valid)
-
-#define GEANY_WINDOW_MINIMAL_WIDTH		550
-#define GEANY_WINDOW_MINIMAL_HEIGHT		GEANY_DEFAULT_DIALOG_HEIGHT
-
-#endif	/* GEANY_DISABLE_DEPRECATED */
-
 G_END_DECLS
 
 #endif /* GEANY_PLUGIN_DATA_H */
