@@ -1,8 +1,7 @@
 /*
  *      project.h - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2007-2012 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
- *      Copyright 2007-2012 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
+ *      Copyright 2007 The Geany contributors
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -23,6 +22,9 @@
 #ifndef GEANY_PROJECT_H
 #define GEANY_PROJECT_H 1
 
+#include <glib.h>
+#include <glib-object.h>
+
 G_BEGIN_DECLS
 
 #define GEANY_PROJECT_EXT				"geany"
@@ -38,23 +40,21 @@ typedef struct GeanyProject
 	/** Identifier whether it is a pure Geany project or modified/extended
 	 * by a plugin. */
 	gint type;
-	gchar **file_patterns;	/**< Array of filename extension patterns. */
+	GStrv file_patterns;	/**< Array of filename extension patterns. */
 
 	struct GeanyProjectPrivate	*priv;	/* must be last, append fields before this item */
-#ifdef GEANY_PRIVATE
-	/* Do not use following fields in plugins */
-	GPtrArray *build_filetypes_list; /* Project has custom filetype builds for these. */
-	gint long_line_behaviour; /* 0 - disabled, 1 - follow global settings, 2 - enabled (custom) */
-	gint long_line_column; /* Long line marker position. */
-#endif
 }
 GeanyProject;
 
 
+void project_write_config(void);
+
+
+#ifdef GEANY_PRIVATE
+
 typedef struct ProjectPrefs
 {
 	gchar *session_file;
-	gboolean project_session;
 	gboolean project_file_in_basedir;
 } ProjectPrefs;
 
@@ -66,11 +66,11 @@ void project_init(void);
 void project_finalize(void);
 
 
-void project_new(void);
+void project_new(gboolean from_folder);
 
 void project_open(void);
 
-void project_close(gboolean open_default);
+gboolean project_close(gboolean open_default);
 
 void project_properties(void);
 
@@ -96,6 +96,8 @@ void project_setup_prefs(void);
 
 void project_apply_prefs(void);
 
+#endif /* GEANY_PRIVATE */
+
 G_END_DECLS
 
-#endif
+#endif /* GEANY_PROJECT_H */
