@@ -32,6 +32,7 @@ typedef struct TMWorkspace
 		(just pointers to source file tags, the tag objects are owned by the source files). @elementtype{TMTag} */
 	GPtrArray *typename_array; /* Typename tags for syntax highlighting (pointers owned by source files) */
 	GPtrArray *global_typename_array; /* Like above for global tags */
+	GHashTable *source_file_map; /* File name -> GPtrArray<TMSourceFile> map to speed up lookups based on file name */
 } TMWorkspace;
 
 
@@ -56,10 +57,12 @@ gboolean tm_workspace_create_global_tags(const char *pre_process, const char **i
 GPtrArray *tm_workspace_find(const char *name, const char *scope, TMTagType type,
 	TMTagAttrType *attrs, TMParserType lang);
 
-GPtrArray *tm_workspace_find_prefix(const char *prefix, TMParserType lang, guint max_num);
+GPtrArray *tm_workspace_find_prefix(const char *prefix,
+	TMSourceFile *current_file, guint current_line, const gchar *current_scope,
+	guint max_num);
 
 GPtrArray *tm_workspace_find_scope_members (TMSourceFile *source_file, const char *name,
-	gboolean function, gboolean member, const gchar *current_scope, gboolean search_namespace);
+	gboolean function, gboolean member, const gchar *current_scope, guint current_line, gboolean search_namespace);
 
 
 void tm_workspace_add_source_file_noupdate(TMSourceFile *source_file);
@@ -69,6 +72,8 @@ void tm_workspace_update_source_file_buffer(TMSourceFile *source_file, guchar* t
 
 void tm_workspace_free(void);
 
+gboolean tm_workspace_is_autocomplete_tag(TMTag *tag, TMSourceFile *current_file,
+	guint current_line, const gchar *current_scope);
 
 #ifdef TM_DEBUG
 void tm_workspace_dump(void);
